
/*******************************************************************************
**
** Concurrent Technologies Corporation (CTC) grants you ("Licensee") a non-
** exclusive, royalty free, license to use, modify and redistribute this
** software in source and binary code form, provided that i) this copyright
** notice and license appear on all copies of the software; and ii) Licensee does
** not utilize the software in a manner which is disparaging to CTC.
**
** This software is provided "AS IS," without a warranty of any kind.  ALL
** EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY
** IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-
** INFRINGEMENT, ARE HEREBY EXCLUDED.  CTC AND ITS LICENSORS SHALL NOT BE LIABLE
** FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
** DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES.  IN NO EVENT WILL CTC  OR ITS
** LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT,
** INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
** CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF
** OR INABILITY TO USE SOFTWARE, EVEN IF CTC  HAS BEEN ADVISED OF THE POSSIBILITY
** OF SUCH DAMAGES.
**
*******************************************************************************/

// Define exception/error codes
var _NoError = 0;
var _GeneralException = 101;
var _ServerBusy = 102;
var _InvalidArgumentError = 201;
var _ElementCannotHaveChildren = 202;
var _ElementIsNotAnArray = 203;
var _NotInitialized = 301;
var _NotImplementedError = 401;
var _InvalidSetValue = 402;
var _ElementIsReadOnly = 403;
var _ElementIsWriteOnly = 404;
var _IncorrectDataType = 405;


// local variable definitions
var apiHandle = null;
var findAPITries = 0;


/*******************************************************************************
**
** Function: doLMSInitialize()
** Returns false if initialize has failed.
**
** Description:
** Initialize communication with LMS by calling the LMSInitialize
** function which will be implemented by the LMS.
**
*******************************************************************************/
function doLMSInitialize()
{
	var api = getAPIHandle();
	
	var result = false;

	if (api != null)
	{
		result = api.LMSInitialize("");
	}

	return result;
}

/*******************************************************************************
**
** Function doLMSFinish()
** Returns true if success false otherwise
**
** Description:
** Close communication with LMS by calling the LMSFinish
** function which will be implemented by the LMS
**
*******************************************************************************/
function doLMSFinish()
{
   var api = getAPIHandle();
   var result = false;
   
   if (api != null)
   {
		result = api.LMSFinish("");
   }

   return result;
}

/*******************************************************************************
**
** Function doLMSGetValue(name)
** Returns value in the lms or null value
**
** Description:
** Wraps the call to the LMS LMSGetValue method
**
*******************************************************************************/
function doLMSGetValue(key)
{
	var api = getAPIHandle();
	var value = null;

	if (api != null)
	{
		value = api.LMSGetValue(key);
	}

	return value;
}

/*******************************************************************************
**
** Function doLMSSetValue(name, value)
** Returns true if sucess, false otherwise
**
** Description:
** Wraps the call to the LMS LMSSetValue function
**
*******************************************************************************/
function doLMSSetValue(key, value)
{
	var api = getAPIHandle();
	var result = false;

	if (api != null)
	{
		result = api.LMSSetValue(key, value);
	}
	
	return result;
}

/*******************************************************************************
**
** Function doLMSCommit()
** Returns true if sucessful, false otherwise.
**
** Description:
** Call the LMSCommit function 
**
*******************************************************************************/
function doLMSCommit()
{
	var api = getAPIHandle();
	var result = false;

	if (api != null)
	{
		result = api.LMSCommit("");
	}

	return result;
}

/*******************************************************************************
**
** Function doLMSGetLastError()
** Return:  The error code that was set by the last LMS function call
**
** Description:
** Call the LMSGetLastError function 
**
*******************************************************************************/
function doLMSGetLastError()
{
	var api = getAPIHandle();
	var errorCode = _GeneralException;

	if (api != null)
	{
		//Do not include the empty string in the method call
		errorCode = api.LMSGetLastError();
	}

	return errorCode;
}

/*******************************************************************************
**
** Function doLMSGetErrorString(errorCode)
** Inputs:  errorCode - Error Code
** Return:  The textual description that corresponds to the input error code
**
** Description:
** Call the LMSGetErrorString function 
**
********************************************************************************/
function doLMSGetErrorString()
{
   var api = getAPIHandle();
   var errorString = "General Exception";
   
   if (api != null)
   {
		errorString = api.LMSGetErrorString("");
   }

	return errorString;
}

/*******************************************************************************
**
** Function doLMSGetDiagnostic(errorCode)
** Inputs:  errorCode - Error Code(integer format), or null
** Return:  The vendor specific textual description that corresponds to the 
**          input error code
**
** Description:
** Call the LMSGetDiagnostic function
**
*******************************************************************************/
function doLMSGetDiagnostic()
{
	var api = getAPIHandle();
	var errorDiagnostic = "Check if API is active and ready to communicate";

	if (api != null)
	{
		errorDiagnostic = api.LMSGetDiagnostic("");
	}

	return errorDiagnostic;
}


/******************************************************************************
**
** Function getAPIHandle()
** Inputs:  None
** Return:  value contained by APIHandle
**
** Description:
** Returns the handle to API object if it was previously set,
** otherwise it returns null
**
*******************************************************************************/
function getAPIHandle()
{
   if (apiHandle == null)
   {
      apiHandle = getAPI();
   }

   return apiHandle;
}


/*******************************************************************************
**
** Function findAPI(win)
** Inputs:  win - a Window Object
** Return:  If an API object is found, it's returned, otherwise null is returned
**
** Description:
** This function looks for an object named API in parent and opener windows
**
*******************************************************************************/
function findAPI(win)
{
	while ((win.API == null) && (win.parent != null) && (win.parent != win))
	{
		findAPITries++;

		if (findAPITries > 5) 
		{
		 return null;
		}

		win = win.parent;

	}

	return win.API;
}



/*******************************************************************************
**
** Function getAPI()
** Inputs:  none
** Return:  If an API object is found, it's returned, otherwise null is returned
**
** Description:
** This function looks for an object named API, first in the current window's 
** frame hierarchy and then, if necessary, in the current window's opener window
** hierarchy (if there is an opener window).
**
*******************************************************************************/
function getAPI()
{
	var theAPI = findAPI(window);

	if ( (theAPI == null) && (window.opener != null) && (typeof(window.opener) != "undefined") )
	{
		theAPI = findAPI(window.opener);
	}

	if ( (top.window.opener !=null) && (top.window.opener.document.API != null) )  
	{
		theAPI = window.top.opener.document.API;
	}

	return theAPI;
}

